@@ -1,7 +1,7 @@
 use serde::{Deserialize, Serialize};
 
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-albumobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct AlbumObject {
     /// The type of the album: `album`, `single`, or `compilation`.
     pub album_type: String,
@@ -42,8 +42,8 @@ pub struct AlbumObject {
     /// The Spotify URI for the album.
     pub uri: String,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-albumrestrictionobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct AlbumRestrictionObject {
     /// The reason for the restriction. Supported values:
     /// * `market` - The content item is not available in the given market.
@@ -51,8 +51,8 @@ pub struct AlbumRestrictionObject {
     /// * `explicit` - The content item is explicit and the user’s account is set to not play explicit content. Additional reasons may be added in the future. **Note**: If you use this field, make sure that your application safely handles unknown values.
     pub reason: String,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-artistobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct ArtistObject {
     /// Known external URLs for this artist.
     external_urls: ExternalUrlObject,
@@ -139,13 +139,15 @@ pub struct ContextObject {
     /// The [Spotify URI](https://developer.spotify.com/documentation/web-api/#spotify-uris-and-ids) for the context.
     uri: String,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
+
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-copyrightobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct CopyrightObject {
     /// The copyright text for this content.
     pub text: String,
     /// The type of copyright: `C` = the copyright, `P` = the sound recording (performance) copyright.
-    r#type: String,
+    #[serde(rename = "type")]
+    _type: String,
 }
 
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-currentlyplayingcontextobject)
@@ -253,6 +255,7 @@ pub struct DisallowsObject {
     transferring_playback: Option<bool>,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-episodeobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct EpisodeObject {
     /// A URL to a 30 second preview (MP3 format) of the episode. `null` if not available.
     audio_preview_url: String,
@@ -298,6 +301,7 @@ pub struct EpisodeObject {
     uri: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-episoderestrictionobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct EpisodeRestrictionObject {
     /// The reason for the restriction. Supported values:
     /// * `market` - The content item is not available in the given market.
@@ -325,8 +329,8 @@ pub struct ExplicitContentSettingsObject {
     /// When `true`, indicates that the explicit content setting is locked and can’t be changed by the user.
     filter_locked: bool,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-externalidobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct ExternalIdObject {
     /// [International Article Number](https://en.wikipedia.org/wiki/International_Article_Number)
     pub ean: String,
@@ -335,22 +339,22 @@ pub struct ExternalIdObject {
     /// [Universal Product Code](https://en.wikipedia.org/wiki/Universal_Product_Code)
     pub upc: String,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-externalurlobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct ExternalUrlObject {
     /// The [Spotify URL](https://developer.spotify.com/documentation/web-api/#spotify-uris-and-ids) for the object.
     pub spotify: String,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-followersobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct FollowersObject {
     /// A link to the Web API endpoint providing full details of the followers; `null` if not available. Please note that this will always be set to null, as the Web API does not support it at the moment.
     href: String,
     /// The total number of followers.
     total: usize,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-imageobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct ImageObject {
     /// The image height in pixels. If unknown: `null` or not returned.
     pub height: Option<u32>,
@@ -455,6 +459,7 @@ pub struct PlaylistObject {
     uri: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-playlisttrackobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct PlaylistTrackObject {
     /// The date and time the track or episode was added. Note that some very old playlists may return `null` in this field.
     //added_at: Timestamp,
@@ -466,6 +471,7 @@ pub struct PlaylistTrackObject {
     track: PlaylistItemType<TrackObject, EpisodeObject>,
 }
 
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub enum PlaylistItemType<T, E> {
     Track(T),
     Episode(E),
@@ -506,6 +512,7 @@ pub struct PrivateUserObject {
     uri: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-publicuserobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct PublicUserObject {
     /// The name displayed on the user’s profile. `null` if not available.
     display_name: String,
@@ -525,19 +532,24 @@ pub struct PublicUserObject {
     uri: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-recommendationseedobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct RecommendationSeedObject {
     /// The number of tracks available after min_* and max_* filters have been applied.
-    after_filtering_size: usize, // afterFilteringSize
+    #[serde(rename = "afterFilteringSize")]
+    after_filtering_size: usize,
     /// The number of tracks available after relinking for regional availability.
-    after_relinking_size: usize, // afterRelinkingSize
+    #[serde(rename = "afterRelinkingSize")]
+    after_relinking_size: usize,
     /// A link to the full track or artist data for this seed. For tracks this will be a link to a [Track Object](https://developer.spotify.com/documentation/web-api/reference/#object-trackobject). For artists a link to [an Artist Object](https://developer.spotify.com/documentation/web-api/reference/#object-artistobject). For genre seeds, this value will be `null`.
     href: String,
     /// The id used to select this seed. This will be the same as the string used in the `seed_artists`, `seed_tracks` or `seed_genres` parameter.
     id: String,
     /// The number of recommended tracks available for this seed.
-    initialPoolSize: usize,
+    #[serde(rename = "initialPoolSize")]
+    initial_pool_size: usize,
     /// The entity type of this seed. One of `artist`, `track` or `genre`.
-    r#type: String,
+    #[serde(rename = "type")]
+    _type: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-recommendationsobject)
 pub struct RecommendationsObject {
@@ -547,6 +559,7 @@ pub struct RecommendationsObject {
     tracks: Vec<SimplifiedTrackObject>,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-resumepointobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct ResumePointObject {
     /// Whether or not the episode has been fully played by the user.
     fully_played: bool,
@@ -582,6 +595,7 @@ pub struct SavedTrackObject {
     track: TrackObject,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-showobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct ShowObject {
     /// A list of the countries in which the show can be played, identified by their [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code.
     available_markets: Vec<String>,
@@ -612,11 +626,13 @@ pub struct ShowObject {
     /// The publisher of the show.
     publisher: String,
     /// The object type: “show”.
-    r#type: String,
+    #[serde(rename = "initialPoolSize")]
+    _type: String,
     /// The [Spotify URI](https://developer.spotify.com/documentation/web-api/#spotify-uris-and-ids) for the show.
     uri: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-simplifiedalbumobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct SimplifiedAlbumObject {
     /// The type of the album: `album`, `single`, or `compilation`.
     album_type: String,
@@ -661,6 +677,7 @@ pub struct SimplifiedArtistObject {
     uri: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-simplifiedepisodeobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct SimplifiedEpisodeObject {
     /// A URL to a 30 second preview (MP3 format) of the episode. `null` if not available.
     audio_preview_url: String,
@@ -704,6 +721,7 @@ pub struct SimplifiedEpisodeObject {
     uri: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-simplifiedplaylistobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct SimplifiedPlaylistObject {
     /// `true` if the owner allows other users to modify the playlist.
     collaborative: bool,
@@ -733,6 +751,7 @@ pub struct SimplifiedPlaylistObject {
     uri: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-simplifiedshowobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct SimplifiedShowObject {
     /// A list of the countries in which the show can be played, identified by their [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code.
     available_markets: Vec<String>,
@@ -765,8 +784,8 @@ pub struct SimplifiedShowObject {
     /// The [Spotify URI](https://developer.spotify.com/documentation/web-api/#spotify-uris-and-ids) for the show.
     uri: String,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-simplifiedtrackobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct SimplifiedTrackObject {
     /// The artists who performed the track. Each artist object includes a link in `href` to more detailed information about the artist.
     artists: Vec<ArtistObject>,
@@ -804,6 +823,7 @@ pub struct SimplifiedTrackObject {
     uri: String,
 }
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-trackobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct TrackObject {
     /// The album on which the track appears. The album object includes a link in `href` to full information about the album.
     album: SimplifiedAlbumObject,
@@ -848,8 +868,8 @@ pub struct TrackObject {
     /// The [Spotify URI](https://developer.spotify.com/documentation/web-api/#spotify-uris-and-ids) for the track.
     uri: String,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 /// [Reference](https://developer.spotify.com/documentation/general/guides/track-relinking-guide/)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct LinkedFrom {
     pub external_urls: ExternalUrlObject,
     pub href: String,
@@ -857,8 +877,9 @@ pub struct LinkedFrom {
     r#type: String,
     pub uri: String,
 }
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
+
 /// [Reference](https://developer.spotify.com/documentation/web-api/reference/#object-trackrestrictionobject)
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Eq)]
 pub struct TrackRestrictionObject {
     /// The reason for the restriction. Supported values:
     /// * `market` - The content item is not available in the given market.
